.. Installation

Installation
============

spreg is installable using the Python Package Manager, `pip`. To install::

    pip install spreg

Further, all of the stable functionality is *also* available in PySAL, the 
Python Spatial Analysis Library. PySAL can be installed using `pip` or `conda`::

    pip install pysal #or
    conda install pysal
